@@ -1093,12 +1093,11 @@ function widgetHandler:Shutdown()
   return
 end
 
-function widgetHandler:Update()
-  local deltaTime = Spring.GetLastUpdateSeconds()
+function widgetHandler:Update(dt)
   -- update the hour timer
-  hourTimer = (hourTimer + deltaTime) % 3600.0
+  hourTimer = (hourTimer + dt) % 3600.0
   for _,w in ipairs(self.UpdateList) do
-    w:Update(deltaTime)
+    w:Update(dt)
   end
   return
 end
